pub struct Determinishtic { /* private fields */ }Expand description
Implementations
Sourceimpl Determinishtic
impl Determinishtic
Sourcepub async fn new(
component: impl ConnectTo<Client> + 'static,
) -> Result<Self, Error>
pub async fn new( component: impl ConnectTo<Client> + 'static, ) -> Result<Self, Error>
Create a new Determinishtic instance from a sacp ConnectTo component.
This spawns a background task to run the connection to the agent. The component will be used to communicate with an LLM agent.
Sourcepub fn think<'bound, Output>(&self) -> ThinkBuilder<'bound, Output>
pub fn think<'bound, Output>(&self) -> ThinkBuilder<'bound, Output>
Start building a think block.
Returns a ThinkBuilder that can be used to compose the prompt
and register tools. The builder is consumed when awaited.